/**
 *  Enum that decides what action to take if a problem is detected.
 */
export declare enum Action {
    /** Ignore the error and continue */
    IGNORE = "",
    /** Warn about the error and continue */
    WARN = "warn",
    /** Warn about the error and break */
    ERROR = "error",
}
/**
 * Options that are passed to base64
 */
export interface Options {
    /** Decides which URLs to encode. Anything that is matched by a regexp in the include array will be converted  */
    include: RegExp[];
    /** Decides which URLs to encode. Anything that is matched by a regexp in the exclude array will not be converted */
    exclude: RegExp[];
    /** Only images which are smaller than `maxImageSize` after they are encoded will be inlined */
    maxImageSize: number;
    /** Maximum number of warnings that should be reported */
    maxReported: number;
    /** Decides what to do if an image file is not found */
    actOnMissingFile: Action;
    /** Decides what to do if an image is found that is too big */
    actOnLargeFile: Action;
    /** Decodes what to do if the same image is encoded more than once */
    actOnEncodedTwice: Action;
    /** If set to true, include the original URL as a comment */
    originalAsComment: boolean;
}
export declare function base64(baseDir: string, options: Partial<Options>): any;
