"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var fs = require("fs");
var Datauri = require('datauri');
var func = require('rework-plugin-function');
/**
 *  Enum that decides what action to take if a problem is detected.
 */
var Action;
(function (Action) {
    /** Ignore the error and continue */
    Action["IGNORE"] = "";
    /** Warn about the error and continue */
    Action["WARN"] = "warn";
    /** Warn about the error and break */
    Action["ERROR"] = "error";
})(Action = exports.Action || (exports.Action = {}));
;
;
function base64(baseDir, options) {
    var opts = Object.assign({
        include: [],
        exclude: [/.*/],
        maxImageSize: 8192,
        maxReported: 10,
        actOnMissingFile: Action.ERROR,
        actOnLargeFile: Action.WARN,
        actOnEncodedTwice: Action.WARN,
        originalAsComment: false
    }, options);
    var cache = {};
    var reported = 0;
    function error(value, action, url, msg) {
        msg = 'Image file ' + url + ' ' + msg;
        if (action === Action.ERROR) {
            console.error(msg);
            throw new Error(msg);
        }
        else if (action === Action.WARN) {
            if (reported++ < opts.maxReported) {
                console.warn(msg);
            }
        }
        return value;
    }
    function url(fn) {
        return func({
            url: function (path) {
                path = path.split('"').join('');
                path = path.split('\'').join('');
                var oldValue = path.trim();
                var newValue = fn.call(this, oldValue);
                if (!newValue) {
                    return 'url("' + oldValue + '")';
                }
                else if (opts.originalAsComment) {
                    return '/*' + oldValue + '*/ url("' + newValue + '")';
                }
                else {
                    return 'url("' + newValue + '")';
                }
            }
        }, false);
    }
    function matches(url) {
        return !url.startsWith('data:') &&
            (opts.include.some(function (re) { return !!url.match(re); }) || !opts.exclude.some(function (re) { return !!url.match(re); }));
    }
    return url(function (url) {
        if (matches(url)) {
            if (cache[url]) {
                return error(cache[url], opts.actOnEncodedTwice, url, "is encoded more than once");
            }
            else {
                var file = path.resolve(baseDir, url);
                if (fs.existsSync(file)) {
                    var data = new Datauri(file);
                    if (data.content.length < opts.maxImageSize) {
                        return cache[url] = data.content;
                    }
                    else {
                        return error(undefined, opts.actOnLargeFile, url, 'is too large');
                    }
                }
                else {
                    return error(undefined, opts.actOnMissingFile, url, 'is missing');
                }
            }
        }
        else {
            return undefined;
        }
    });
}
exports.base64 = base64;
//# sourceMappingURL=index.js.map